from datetime import datetime

from peewee import CharField
from peewee import DateTimeField
from peewee import ForeignKeyField
from peewee import IntegerField
from peewee import Model
from peewee import SqliteDatabase
from peewee import TextField

db = SqliteDatabase('alyaht.db')


class BaseModel(Model):
    class Meta:
        database = db


class Client(BaseModel):
    name = CharField()
    nrle_id = CharField(unique=True)
    created_at = DateTimeField(default=datetime.now)

    @classmethod
    def find_client_by_id(cls, id):
        return (cls
                .get(cls.id == id))

    @classmethod
    def find_client_by_nrle(cls, id):
        return (cls
                .get(cls.nrle_id == id))


class Nfse(BaseModel):
    client = ForeignKeyField(Client, backref='nfses')
    nfse_number = IntegerField()
    service_value = IntegerField()
    services_provided = TextField()
    created_at = DateTimeField(default=datetime.now)

    @classmethod
    def find_nfse_by_number(cls, number):
        return (cls
                .get(cls.nfse_number == number))

    @classmethod
    def find_nfse_by_client(cls, client_id):
        return cls.select().where(cls.client == client_id)
